@@ -3,12 +3,12 @@ from django.utils.translation import ugettext_lazy as _
 from dockitcms.mixins import BaseMixin, register_mixin
 from dockitcms.models import Subsite, ViewPoint
 
-from models import Widget
+from models import BlockWidget
 
 from dockit import schema
 
 class WidgetMixin(BaseMixin):
-    widgets = schema.ListField(schema.SchemaField(Widget))
+    widgets = schema.ListField(schema.SchemaField(BlockWidget))
     
     class Meta:
         verbose_name = 'widget'
